@@ -8,9 +8,9 @@ use Cwd ();
 
 require Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw(file_exists l_abs_path);
+our @EXPORT_OK = qw(file_exists l_abs_path dir_empty);
 
-our $VERSION = '0.26'; # VERSION
+our $VERSION = '0.27'; # VERSION
 
 our %SPEC;
 
@@ -37,6 +37,16 @@ sub l_abs_path {
     "$parent/$leaf";
 }
 
+sub dir_empty {
+    my ($dir) = @_;
+    return undef unless (-d $dir);
+    return undef unless opendir my($dh), $dir;
+    my @d = grep {$_ ne '.' && $_ ne '..'} readdir($dh);
+    my $res = !@d;
+    #$log->tracef("dir_is_empty(%s)? %d", $dir, $res);
+    $res;
+}
+
 1;
 # ABSTRACT: File-related utilities
 
@@ -50,14 +60,15 @@ SHARYANTO::File::Util - File-related utilities
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 SYNOPSIS
 
- use SHARYANTO::File::Util qw(file_exists l_abs_path);
+ use SHARYANTO::File::Util qw(file_exists l_abs_path dir_empty);
 
  print "file exists" if file_exists("/path/to/file/or/dir");
  print "absolute path = ", l_abs_path("foo");
+ print "dir exists and is empty" if dir_empty("/path/to/dir");
 
 =head1 DESCRIPTION
 
@@ -103,8 +114,27 @@ Mnemonic: l_abs_path -> abs_path is analogous to lstat -> stat.
 
 Note: currently uses hardcoded C</> as path separator.
 
+=head2 dir_empty($dir) => BOOL
+
+Will return true if C<$dir> exists and is empty.
+
+=head1 FAQ
+
+=head2 Where is file_empty()?
+
+For checking if some path exists, is a regular file, and is empty (content is
+zero-length), you can simply use the C<-z> filetest operator.
+
+=head1 DESCRIPTION
+
+
+This module has L<Rinci> metadata.
+
 =head1 FUNCTIONS
 
+
+None are exported by default, but they are exportable.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
